![PyPI - Downloads](https://img.shields.io/pypi/dm/abstractEasyT)
![PyPI](https://img.shields.io/pypi/v/abstractEasyT)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/abstractEasyT)
![PyPI - License](https://img.shields.io/pypi/l/abstractEasyT)

# abstractEasyT


easyT, easyTo trade, eastTo use!
